======================
IL-2 FB Mission Parser
======================

|pypi_package| |python_versions| |docs| |license|

|unix_build| |windows_build| |requirements|

|coverage_status| |codeclimate| |codacy| |quality| |health|


This is a library for parsing mission files of ``IL-2 Forgotten Battles``. It
produces detailed information about missions.

Please, `read the docs`_ to get full information about this project.

You can dig around `Wiki pages`_ also.

And you can see how it works live on `project's demo page`_.


.. |pypi_package| image:: http://img.shields.io/pypi/v/il2fb-mission-parser.svg?style=flat
   :target: http://badge.fury.io/py/il2fb-mission-parser/

.. |python_versions| image:: https://img.shields.io/badge/Python-2.7,3.4,3.5,3.6-brightgreen.svg?style=flat
   :alt: Supported versions of Python

.. |docs| image:: https://readthedocs.org/projects/il-2-missions-parser/badge/?version=latest&style=flat
   :target: `read the docs`_
   :alt: Documentation

.. |license| image:: https://img.shields.io/badge/license-LGPLv3-brightgreen.svg?style=flat
   :target: https://github.com/IL2HorusTeam/il2fb-mission-parser/blob/master/LICENSE

.. |unix_build| image:: http://img.shields.io/travis/IL2HorusTeam/il2fb-mission-parser.svg?style=flat&branch=master
   :target: https://travis-ci.org/IL2HorusTeam/il2fb-mission-parser
   :alt: Build status of the master branch on Unix

.. |windows_build| image:: https://ci.appveyor.com/api/projects/status/f92qc8g689es612d/branch/master?svg=true
   :target: https://ci.appveyor.com/project/oblalex/il2fb-mission-parser/branch/master
   :alt: Build status of the master branch on Windows

.. |coverage_status| image:: https://codecov.io/github/IL2HorusTeam/il2fb-mission-parser/coverage.svg?branch=master
   :target: https://codecov.io/github/IL2HorusTeam/il2fb-mission-parser?branch=master
   :alt: Test coverage

.. |codeclimate| image:: https://codeclimate.com/github/IL2HorusTeam/il2fb-mission-parser/badges/gpa.svg
   :target: https://codeclimate.com/github/IL2HorusTeam/il2fb-mission-parser
   :alt: Code Climate

.. |codacy| image:: https://www.codacy.com/project/badge/4c79f2cb39234620bce5d4c49a54be52
   :target: https://www.codacy.com/public/IL2HorusTeam/il2fbmissionparser/dashboard
   :alt: Codacy Code Review

.. |quality| image:: https://scrutinizer-ci.com/g/IL2HorusTeam/il2fb-mission-parser/badges/quality-score.png?b=master&style=flat
   :target: https://scrutinizer-ci.com/g/IL2HorusTeam/il2fb-mission-parser/?branch=master
   :alt: Scrutinizer Code Quality

.. |health| image:: https://landscape.io/github/IL2HorusTeam/il2fb-mission-parser/master/landscape.png?style=flat
   :target: https://landscape.io/github/IL2HorusTeam/il2fb-mission-parser/master
   :alt: Code Health

.. |requirements| image:: https://requires.io/github/IL2HorusTeam/il2fb-mission-parser/requirements.svg?branch=master&style=flat
   :target: https://requires.io/github/IL2HorusTeam/il2fb-mission-parser/requirements/?branch=master
   :alt: Requirements Status


.. _read the docs: http://il-2-missions-parser.readthedocs.org/en/latest/
.. _Wiki pages: https://github.com/IL2HorusTeam/il2fb-mission-parser/wiki
.. _project's demo page: http://il2horusteam.github.io/il2fb-mission-parser/
